------------------------------------------------------------------
-- Name: EventHandler								  			--
-- Description: handles all the UI events needed for the addon 	--
------------------------------------------------------------------

MTSLUI_EVENT_HANDLER = {
	-- flags keeping track if window is open or not
	ui_trade_open = 0,
	ui_craft_open = 0,
    addon_loaded = 0,

	---------------------------------------------------------------------------------------
	-- Event started when our addon is fully loaded
	---------------------------------------------------------------------------------------
	PLAYER_LOGIN = function (self)
        if MTSLUI_TOOLS:SetAddonLocale() then
		    print(MTSLUI_FONTS.COLORS.TEXT.TITLE .. MTSL_ADDON.NAME .. MTSLUI_FONTS.COLORS.TEXT.NORMAL .. " (by " .. MTSL_ADDON.AUTHOR .. ")" .. MTSLUI_FONTS.COLORS.TEXT.TITLE .. " v" .. MTSL_ADDON.VERSION .. " loaded!")
		    -- load the data for the player
		    MTSL_TOOLS:LoadPlayer()
            self.addon_loaded = 1
        else
            self.addon_loaded = 0
        end
	end,
	
	---------------------------------------------------------------------------------------
	-- Event started when a crafting window is closed
	---------------------------------------------------------------------------------------
	CRAFT_CLOSE = function (self)
		self.ui_craft_open = 0
		-- if we have a tradeskill window open, reanchor togglebutton and refresh frame
		if self.ui_trade_open > 0 then
			self:TRADE_SKILL_SHOW()
			self:TRADE_SKILL_UPDATE()
		-- no other window was open so close the addon
		else
			MTSLUI_TOGGLE_BUTTON:Hide()
			MTSLUI_MISSING_TRADESKILLS_FRAME:Hide()
		end
	end,
	
	---------------------------------------------------------------------------------------
	-- Event started when a crafting window is opened
	---------------------------------------------------------------------------------------
	CRAFT_SHOW = function (self)
		self.ui_craft_open = 1
		MTSLUI_TOGGLE_BUTTON:SwapToCraftMode()
        MTSLUI_TOGGLE_BUTTON:Show()
		MTSLUI_MISSING_TRADESKILLS_FRAME:NoSkillSelected()
	end,
	
	---------------------------------------------------------------------------------------
	-- Event started when a crafting window is updated
	---------------------------------------------------------------------------------------
	CRAFT_UPDATE = function (self)
		MTSL_TOOLS:UpdateCurrentCraftInfo()
		MTSLUI_MISSING_TRADESKILLS_FRAME:RefreshUI()
	end,
		
	---------------------------------------------------------------------------------------
	-- Event started when a skill point is gained or unlearned a profession
	---------------------------------------------------------------------------------------
	SKILL_LINES_CHANGED = function (self)
		-- Check if we unlearned a profession
		MTSL_TOOLS:CheckProfessions()

		-- update craft skills if open
		if self.ui_craft_open > 0 then
			MTSL_TOOLS:UpdateCurrentCraftInfo()
		end
		-- update trade skills if open
		if self.ui_trade_open > 0 then
			MTSL_TOOLS:UpdateCurrentTradeSkillInfo()
		end
	end,
	
	---------------------------------------------------------------------------------------
	-- Event started when a trade skill windows is closed
	---------------------------------------------------------------------------------------
	TRADE_SKILL_CLOSE = function (self)
		self.ui_trade_open = 0
		-- if we have a tradeskill window open, reanchor togglebutton and refresh frame
		if self.ui_craft_open > 0 then
			self:CRAFT_SHOW()
			self:CRAFT_UPDATE()
		-- no other window was open so close the addon
		else
			MTSLUI_TOGGLE_BUTTON:Hide()
			MTSLUI_MISSING_TRADESKILLS_FRAME:Hide()
		end
	end,
	
	---------------------------------------------------------------------------------------
	-- Event started when a trade skill windows is opened
	---------------------------------------------------------------------------------------
	TRADE_SKILL_SHOW = function (self)
        MTSLUI_TOGGLE_BUTTON:SwapToTradeSkillMode()
		MTSLUI_TOGGLE_BUTTON:Show()
		MTSLUI_MISSING_TRADESKILLS_FRAME:NoSkillSelected()
		self.ui_trade_open = 1
	end,

	---------------------------------------------------------------------------------------
	-- Event started when a trade skill windows is updated
	---------------------------------------------------------------------------------------
	TRADE_SKILL_UPDATE = function (self)
		MTSL_TOOLS:UpdateCurrentTradeSkillInfo()
		MTSLUI_MISSING_TRADESKILLS_FRAME:RefreshUI()
	end,
	
	---------------------------------------------------------------------------------------
	-- Event started when a skill is learned from trainer
	---------------------------------------------------------------------------------------
	TRAINER_UPDATE = function (self)
		MTSLUI_MISSING_TRADESKILLS_FRAME:RefreshUI()
	end,

	---------------------------------------------------------------------------------------
	-- Handles a slash command for this addon
	--
	-- @msg:			string		The argument for the slash command
	---------------------------------------------------------------------------------------
    SLASH_COMMAND = function (self, msg)
		if msg == nil or msg == "" then
		    -- toggle frame
			MTSLUI_DEBUG("MTSL: toggles account wide main frame - IN PROGRESS")
			--MTSLUI_ACCOUNT_FRAME:Toggle()
		elseif msg == "show" then
		    -- show main frame
			MTSLUI_DEBUG("MTSL: shows account wide main frame - IN PROGRESS")
			--MTSLUI_ACCOUNT_FRAME:Show()
		elseif msg == "hide" then
		    -- hide main frame
			MTSLUI_DEBUG("MTSL: hides account wide main frame - IN PROGRESS")
			--MTSLUI_ACCOUNT_FRAME:Hide()
		elseif msg == "about" then
            MTSLUI_TOOLS:PrintAboutMessage()
		elseif msg == "summary" then
			MTSLUI_TOOLS:PrintSummary()
        else
            MTSLUI_TOOLS:PrintHelpMessage()
		end
    end,

	---------------------------------------------------------------------------------------
	-- Initialise the handler and hook all events
	---------------------------------------------------------------------------------------
	Initialise = function (self)
		-- Create an "empty" frame to hook onto
		local event_frame = CreateFrame("FRAME")
		-- Set function how to react on event
		event_frame:SetScript("OnEvent", function(eventframe, event, arg1)
			-- Call corresponding function for the thrown event
            -- only execute the event if the addon is loaded OR the event = player_login
            if self.addon_loaded == 1 or event == "PLAYER_LOGIN" then
                self[event](self)
            end
		end)
		-- Event thrown when player has logged in
		event_frame:RegisterEvent("PLAYER_LOGIN")
		-- Events for crafts (= Enchanting)
		event_frame:RegisterEvent("CRAFT_CLOSE")
		event_frame:RegisterEvent("CRAFT_SHOW")
		event_frame:RegisterEvent("CRAFT_UPDATE")
		-- Gained a skill point
		event_frame:RegisterEvent("SKILL_LINES_CHANGED")
		-- Events for trade skills (= all but enchanting)
		event_frame:RegisterEvent("TRADE_SKILL_CLOSE")
		event_frame:RegisterEvent("TRADE_SKILL_SHOW")
		event_frame:RegisterEvent("TRADE_SKILL_UPDATE")
		-- Learned Skill from trainer
		event_frame:RegisterEvent("TRAINER_UPDATE")
	end,
}